@@ -66,7 +66,9 @@ plotdata <- function(data,
       n2 <- fp + tn
     }
 
-  if(tp>n1 || fp>n2)stop("the data is inconsistent")
+
+  # Data errors
+  if(any(tp>n1) || any(fp>n2))stop("the data is inconsistent")
 
   if(!missing(data)){
     tpr <-  tp / n1
